@@ -8,29 +8,33 @@
 
 
 from dataclasses import dataclass
+import json
 
-from http_tools import AbmServiceConnector
+from http_tools.http_server_connector import HttpServerConnector
 
 
 class DetectorHttpConnector:
-    @dataclass(kw_only=True)
-    class Config(AbmServiceConnector.Config):
+    @dataclass
+    class Context(HttpServerConnector.Context):
         project_name: str
 
-    Context = AbmServiceConnector.Context
+    Config = HttpServerConnector.Config
 
     def __init__(self, config: Config, context: Context) -> None:
         self.config = config
-        self._connector = AbmServiceConnector(config, context)
+        self.context = context
+        self._connector = HttpServerConnector(config, context)
 
     async def correct_settings(self, stream_url: str, correct_file_id: str, token: str) -> bool:
-        payload = {
+        payload = json.dumps(
+            {
                 "correct_file_id": correct_file_id,
                 "token": token,
                 "stream_url": stream_url
-        }
+            }
+        ).encode()
         answer = await self._connector.post("/settings/correct", payload=payload, headers=self._construct_headers())
         return answer["done"]
 
     def _construct_headers(self) -> dict[str, str]:
-        return {"server_name": self.config.server_name}
+        return {"server_name": self.context.project_name}
